@@ -1,7 +1,8 @@
-calcGabrielGraph2D=function(Data,PlotIt=F){
+calcGabrielGraph2D=function(Data, PlotIt=F){
   
   requireNamespace('spdep')
   requireNamespace('sp')
+  
   coords <- sp::coordinates(Data)
   Liste=spdep::gabrielneigh(coords)
 
@@ -16,5 +17,6 @@ calcGabrielGraph2D=function(Data,PlotIt=F){
     Adj[Liste$from[i],Liste$to[i]]=1
     Adj[Liste$to[i],Liste$from[i]]=1
   }
-  return(list(Delaunay=Adj))
-}
\ No newline at end of file
+
+  return(Gabriel=Adj)
+}
